import { TypeboxRouteSchema, TypeboxRouteSchemaToSchema } from "../route/typeboxRoute";
import { ZodRouteSchema, ZodRouteSchemaToSchema } from "../route/zodRoute";
import { AnySchema, RequestArgs } from "../types";
import { HttpMethod, JsonFetchResultPromiseLike } from "./fetch";
/**
 * Config for api client
 */
interface ApiClientConfig {
    /**
     * The baseUrl for all requests
     */
    baseUrl?: string;
    /**
     * Extra headers passed in every requests
     */
    headers?: Record<string, string>;
}
/**
 * Create a apiObject that will be used in generated API file
 * @param config Client config
 * @returns Api client that will be used in generated API file
 */
export declare const createApiClient: (config: ApiClientConfig) => {
    fromStaticRoute: <TSchema extends AnySchema>(method: HttpMethod, url: string) => (args: RequestArgs<TSchema>, signal?: AbortSignal) => JsonFetchResultPromiseLike<TSchema>;
    fromZodRoute: <TSchema_1 extends ZodRouteSchema<import("zod").ZodType<any, import("zod").ZodTypeDef, any>, import("zod").ZodType<any, import("zod").ZodTypeDef, any>, Record<number, import("zod").ZodType<any, import("zod").ZodTypeDef, any>>>>(method: HttpMethod, url: string) => (args: RequestArgs<ZodRouteSchemaToSchema<TSchema_1>>, signal?: AbortSignal) => JsonFetchResultPromiseLike<ZodRouteSchemaToSchema<TSchema_1>>;
    fromTypeboxRoute: <TSchema_2 extends TypeboxRouteSchema<import("@sinclair/typebox").TObject<import("@sinclair/typebox").TProperties>, import("@sinclair/typebox").TObject<import("@sinclair/typebox").TProperties>, Record<number, import("../route/typeboxRoute").TypeboxReturnType>>>(method: HttpMethod, url: string) => (args: RequestArgs<TypeboxRouteSchemaToSchema<TSchema_2>>, signal?: AbortSignal) => JsonFetchResultPromiseLike<TypeboxRouteSchemaToSchema<TSchema_2>>;
};
export {};
