import type { HttpError } from "./HttpError";
declare class Event<TArgs> {
    handlers: ((args: TArgs) => void)[];
    register: (handler: (args: TArgs) => void) => () => void;
    execute: (args: TArgs) => void;
    unregister: (handler: (args: TArgs) => void) => void;
}
export declare const prefetchEvent: Event<undefined>;
export declare const successEvent: Event<{
    status: number;
    data: any;
}>;
/**
 * Fired when
 * - FetchError is raised (node-fetch exclusive, https://github.com/node-fetch/node-fetch/blob/main/docs/ERROR-HANDLING.md)
 * - TypeError is raised (https://developer.mozilla.org/en-US/docs/Web/API/Fetch_API/Using_Fetch#checking_that_the_fetch_was_successful)
 * - Responses outside of [200, 300) is received
 *
 * Note, errors handled by httpError will not cause failEvent to fire.
 */
export declare const failEvent: Event<HttpError<any>>;
export declare const finallyEvent: Event<undefined>;
export {};
