import { Static, TAny, TIntersect, TNull, TObject, TUnion, TUnknown } from "@sinclair/typebox";
import { NextApiRequest, NextApiResponse } from "next";
import { OrPromise, ValueOf } from "./utils";
export type TypeboxReturnType = TObject | TNull | TIntersect | TUnion | TAny | TUnknown;
export interface TypeboxRouteSchema<TQuery extends TObject = TObject, TBody extends TObject = TObject, TResponses extends Record<number, TypeboxReturnType> = Record<number, TypeboxReturnType>> {
    method: string;
    query?: TQuery;
    body?: TBody;
    responses: TResponses;
}
export type TypeboxRawType<T> = T extends undefined ? undefined : T extends TypeboxReturnType ? Static<T> : T;
export type TypeboxRouteSchemaToSchema<TSchema extends TypeboxRouteSchema> = {
    query: TypeboxRawType<TSchema["query"]>;
    body: TypeboxRawType<TSchema["body"]>;
    responses: {
        [code in keyof TSchema["responses"] & number]: TypeboxRawType<TSchema["responses"][code]>;
    };
};
export declare const typeboxRouteSchema: <TProps extends TypeboxRouteSchema<TObject<import("@sinclair/typebox").TProperties>, TObject<import("@sinclair/typebox").TProperties>, Record<number, TypeboxReturnType>>>(props: TProps) => TProps;
export declare function typeboxRoute<TSchema extends TypeboxRouteSchema>(schema: TSchema, handler: (req: Omit<NextApiRequest, "body"> & {
    query: TypeboxRawType<TSchema["query"]>;
    body: TypeboxRawType<TSchema["body"]>;
}, res: NextApiResponse<TypeboxRawType<ValueOf<TSchema["responses"]>>>) => OrPromise<Partial<{
    [code in keyof TSchema["responses"] & number]: TypeboxRawType<TSchema["responses"][code]>;
}> | void>): typeof handler;
