import { NextApiRequest, NextApiResponse } from "next";
import { z } from "zod";
import { OrPromise, ValueOf } from "./utils";
export interface ZodRouteSchema<TQuery extends z.ZodType = z.ZodType, TBody extends z.ZodType = z.ZodType, TResponses extends Record<number, z.ZodType> = Record<number, z.ZodType>> {
    method: string;
    query?: TQuery;
    body?: TBody;
    responses: TResponses;
}
export type ZodRawType<T> = T extends undefined ? undefined : T extends z.ZodType ? z.infer<T> : T;
export type ZodRouteSchemaToSchema<TSchema extends ZodRouteSchema> = {
    query: ZodRawType<TSchema["query"]>;
    body: ZodRawType<TSchema["body"]>;
    responses: {
        [code in keyof TSchema["responses"] & number]: ZodRawType<TSchema["responses"][code]>;
    };
};
export declare const zodRouteSchema: <TProps extends ZodRouteSchema<z.ZodType<any, z.ZodTypeDef, any>, z.ZodType<any, z.ZodTypeDef, any>, Record<number, z.ZodType<any, z.ZodTypeDef, any>>>>(props: TProps) => TProps;
export declare function zodRoute<TSchema extends ZodRouteSchema>(schema: TSchema, handler: (req: Omit<NextApiRequest, "body"> & {
    query: ZodRawType<TSchema["query"]>;
    body: ZodRawType<TSchema["body"]>;
}, res: NextApiResponse<ZodRawType<ValueOf<TSchema["responses"]>>>) => OrPromise<Partial<{
    [code in keyof TSchema["responses"] & number]: ZodRawType<TSchema["responses"][code]>;
}> | void>): typeof handler;
